/**
 * @author Sebastian Raß
 * @version 2007-10-27
 *
 */

public class Asset extends SuperAsset {

/*
 * Datenfelder
 */
	
	private String asx;
	private String mms;
	private String displayType;
	private String asset;
 
/*
 * KONSTRUKTOR
 */
	
	/**
	 * Erzeugt ein neues Asset-Objekt
	 * @param url Relativer Pfad der Sendung
	 * @param parentUrl relativer Pfad zum übergeordneten SuperAsset
	 */
	public Asset(String url, String parentUrl) {
		super(url, parentUrl);
		this.asset = requestStringFromServer("http://www.zdf.de" + url + "?&bw=dsl2000&pp=wmp&view=navJson");
		this.displayType = parseDisplaytype(asset);
		System.out.println("#DISPLAY: " +displayType);
		try {
			if (!this.displayType.equalsIgnoreCase("video")) {
				throw new AssetException(1);
			}
			this.subid = parseSubid(asset);
			this.subtitle = parseSubtitle(asset);
			this.asx = parseASX(asset);
			this.mms = parseMMS(requestStringFromServer(parseASX(asset)));
			/*
			System.out.println("###ID: " +super.id);
			System.out.println("#####SUBID: " +subid);
			System.out.println("#######TITLE: " +super.title);
			System.out.println("#########SUBTITLE: " +subtitle);
			System.out.println("###########ASX: " +asx);
			System.out.println("###########MMS: " +mms);
			*/
		}
		catch (AssetException e) {
			System.err.println(e.getMessage());
		}
	}

/*
 * GET-Methoden
 */

	/**
	 * Liest das Datenfeld für die Sendungs-ID aus
	 * @return Sendungs-ID
	 */
	public String getsubID() {
		return this.subid;
	}

	/**
	 * Liest das Datenfeld für den Sendungstitel aus
	 * @return Sendungstitel
	 */
	public String getsubtitle() {
		return this.subtitle;
	}

	/**
	 * Liest das Datenfeld für den ASX-Link aus
	 * @return (ASX-Link)
	 */
	public String getASX() {
		return this.asx;
	}

	/**
	 * Liest das Datenfeld für den MMS-Link aus
	 * @return (MMS-Link)
	 */
	public String getMMS() {
		return this.mms;
	}

	/**
	 * Liest das Datenfeld für den Medien-Typ aus
	 * @return (Medien-Typ)
	 */
	public String getDisplayType() {
		return this.displayType;
	}

/*
 * PARSE-Methoden
 */	

	/**
	 * Extrahiert aus dem Asset-String den ASX-Link
	 * @param asset Inhalt der Assetfile als String
	 * @return ASX-Link
	 */
	public static String parseASX(String asset) {
		String asx = "";
		try {
			if (asset.length() == 0) {
				throw new AssetException(0);
			}
	
			for (int i = 0; i < asset.length(); i++) {
				if(asset.substring(i).startsWith("assetUrl"))
					asx = asset.substring(i);
			}
			
			for (int i = 0; i < asx.length(); i++) {
				if(asx.substring(i).startsWith("http://"))
					asx = asx.substring(i);
			}
			
			for (int i = asx.length() - 1; i > 0; i--) {
				if (asx.substring(0,i).endsWith(".asx"))
					asx = asx.substring(0,i);
			}
			
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return asx;
	}

	/**
	 * Extrahiert den mms-Link aus der asx-Datei
	 * @param asx Inhalt der Asset-Datei
	 * @return MMS-Link
	 */
	public static String parseMMS(String asx) {
		String mms = "";
		try  {
			if (asx.length() == 0) {
				throw new AssetException(0);
			}
	
			for (int i = 0; i < asx.length(); i++) {
				if(asx.substring(i).startsWith("mms:"))
					mms = asx.substring(i);
			}
			
			for (int i = mms.length() - 1; i > 0; i--) {
				if (mms.substring(0,i).endsWith(".wmv"))
					mms = mms.substring(0,i);
			}
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return mms;
	}

/*	public static String parseASX(String asset) {
		String asx = "";
		try  {
			if (asset.length() == 0) throw new AssetException(0);
			int start = asset.indexOf("\"assetUrl\":");
//			System.out.println("2" + start);
			if (start != -1) asx = asset.substring(start + 13);
//			System.out.println("3" + asx);
			
			//int marker = asx.indexOf("http:");
			//if (marker != -1) asx.substring(marker + 1);
//			System.out.println("4" + marker);
//			System.out.println("5" + asx);
			
//			int marker = asx.indexOf(".asx");
//			if (marker != -1) asx.substring(0, marker + 3);
			
			for (int i = asx.length() - 1; i > 0; i--) {
				if (asx.substring(0,i).endsWith(".asx"))
					asx = asx.substring(0,i);
			}
		}
		/*
		try {
			if (asset.length() == 0) throw new AssetException(0);
			for (int i = 0; i < asset.length(); i++) {
				if(asset.substring(i).startsWith("assetUrl"))
					asx = asset.substring(i);
			}
			for (int i = 0; i < asx.length(); i++) {
				if(asx.substring(i).startsWith("http://"))
					asx = asx.substring(i);
			}
			for (int i = asx.length() - 1; i > 0; i--) {
				if (asx.substring(0,i).endsWith(".asx"))
					asx = asx.substring(0,i);
			}
		}/*
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return asx;
	}*/

/*	public static String parseMMS(String asx) {
		String mms = "";
		try  {
			if (asx.length() == 0) throw new AssetException(0);
			
			int start = asx.indexOf("mms:");
			if (start != -1) mms = asx.substring(start);
			
			int marker = mms.indexOf("\"");
			if (marker != -1) mms.substring(marker - 1);
			
			/		
			for (int i = 0; i < asx.length(); i++) {
				if(asx.substring(i).startsWith("mms:"))
					mms = asx.substring(i);
			}
			
			for (int i = mms.length() - 1; i > 0; i--) {
				if (mms.substring(0,i).endsWith(".wmv"))
					mms = mms.substring(0,i);
			}
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		System.out.println("MMS_LINK  " + mms);
		return mms;
	}*/

	/**
	 * Erwartet eine Asset-Datei als String und extrahiert hieraus den Sendungstitel
	 * @param asset Inhalt der Asset-Datei
	 * @return Sendungstitel
	 */
	public static String parseSubtitle(String asset) {
		String subtitle = "";
		/* Warum geht das nicht auf diese Weise mit der methode indexOf()
		try  {
			if (asset.length() == 0) throw new AssetException(0);
			
			int start = asset.indexOf("\"assetTitle\":");
			if (start != -1) subtitle = asset.substring(start + 13);
			
			int marker = subtitle.indexOf("\"");
			if (marker != -1) subtitle.substring(marker + 1);
			
			marker = subtitle.indexOf("\"");
			if (marker != -1) subtitle.substring(0, marker - 1);
		}
		*/
		try  {
			if (asset.length() == 0) {
				throw new AssetException(0);
			}
	
	
			for (int i = 0; i < asset.length(); i++) {
				if(asset.substring(i).startsWith("\"assetTitle\":")) {
					subtitle = asset.substring(i+13);
					break;
				}
			}
			
			for (int i = 0; i < subtitle.length(); i++) {
				if(subtitle.substring(i).startsWith("\"")) {
					subtitle = subtitle.substring(i+1);
					break;
				}
			}
			
			for (int i = 1; i < subtitle.length(); i++) {
				if (subtitle.substring(0,i).endsWith("\"")) {
					subtitle = subtitle.substring(0,i-1);
					break;
				}
			}
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return subtitle;
	}

	/**
	 * Erwartet eine Asset-Datei als String und extrahiert hieraus die Sendungs-ID
	 * @param asset Inhalt der Asset-Datei
	 * @return Sendungs-ID
	 */	
	public static String parseSubid(String asset) {
	/*	String subid = "";
		try  {
			if (asset.length() == 0) throw new AssetException(0);
			
			int start = asset.indexOf("\"assetId\":");
			if (start != -1) subid = asset.substring(start + 10);
			
			int marker = subid.indexOf("\"");
			if (marker != -1) subid.substring(marker + 1);
			
			marker = subid.indexOf("\"");
			if (marker != -1) subid.substring(0, marker - 1);
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return subid;*/
		String subid = "";
		try  {
			if (asset.length() == 0) {
				throw new AssetException(0);
			}
	
	
			for (int i = 0; i < asset.length(); i++) {
				if(asset.substring(i).startsWith("\"assetId\":")) {
					subid = asset.substring(i+10);
					break;
				}
			}
			
			for (int i = 0; i < subid.length(); i++) {
				if(subid.substring(i).startsWith("\"")) {
					subid = subid.substring(i+1);
					break;
				}
			}
			
			for (int i = 1; i < subid.length(); i++) {
				if (subid.substring(0,i).endsWith("\"")) {
					subid = subid.substring(0,i-1);
					break;
				}
			}
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return subid;
	}


	/*public static String parseDisplaytype(String asset) {
		String type = "";
		try  {
			if (asset.length() == 0) throw new AssetException(0);
			
			int start = asset.indexOf("\"assetDisplayType\":");
			if (start != -1) type = asset.substring(start + 19);
			
			int marker = type.indexOf("\"");
			if (marker != -1) type.substring(marker + 1);
			
			marker = type.indexOf("\"");
			if (marker != -1) type.substring(0, marker - 1);
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return type;
	}
	
	
*/

	/**
	 * Erwartet eine Asset-Datei als String und extrahiert hieraus den Medientyp
	 * @param asset Inhalt der Asset-Datei
	 * @return Medientyp
	 */
	public static String parseDisplaytype(String asset) {
		String type = "";
		try  {
			if (asset.length() == 0) {
				throw new AssetException(0);
			}
			for (int i = 0; i < asset.length(); i++) {
				if(asset.substring(i).startsWith("\"assetDisplayType\":")) {
					type = asset.substring(i+19);
					break;
				}
			}
			for (int i = 0; i < type.length(); i++) {
				if(type.substring(i).startsWith("\"")) {
					type = type.substring(i+1);
					break;
				}
			}
			for (int i = 1; i < type.length(); i++) {
				if (type.substring(0,i).endsWith("\"")) {
					type = type.substring(0,i-1);
					break;
				}
			}
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return type;
	}
}
