/**
 * @author Sebastian Raß
 * @version 2007-10-27
 *
 */

import java.util.*;
import java.io.*;

public class ContentList {

	private String content;
	private LinkedList contentList= new LinkedList();
	
	public ContentList() {
		this.content = SuperAsset.requestStringFromServer("http://www.zdf.de/ZDFmediathek/inhalt?&bw=dsl1000&pp=wmp&view=navJson");
		this.contentList = createContentList(content);
	}
	
	/**
	 * Erzeugt eine Inhaltsliste als LinkedList
	 * @param input Inhaltsdatei der ZDFmediathek
	 * @return Inhalt der ZDFmediathek als LinkedList
	 */
	public LinkedList createContentList(String input) {
		int counter = 0;
		int superCounter = 0;
		LinkedList<SuperAsset> list = new LinkedList();
		while (SuperAsset.parseURL(input) != "") {
		String url = SuperAsset.parseURL(input);
		if (url != "") {
			System.out.println(">>>>> creating new Collection");
			input = input.substring(input.indexOf(url) + url.length());
			System.out.println("------------------------");
			System.out.println(url);
			String parentUrl = url;
			String content = SuperAsset.requestStringFromServer("http://www.zdf.de" + url + "?&bw=dsl2000&pp=wmp&view=navJson");
			boolean asset = SuperAsset.isAssetfile(content);
			System.out.println(url);
			if (asset) {
				SuperAsset element = new Asset(url, parentUrl);
				if (list.add(element)) System.out.println("Element added");
				counter++;
			}
			else {
				SuperAsset element = new SuperAsset(url, parentUrl);
				if (list.add(element)) System.out.println("<<<<< Collection complete");
				superCounter++;
			}
		}
		}
		System.out.println(superCounter + " Themen gefunden");
		System.out.println("Hinweis: Einige Feeds können keinen mms-Link enthalten");
		return list;
	}



	/**
	 * Erzeugt eine Indexdatei der Inhaltsliste
	 * @param dir Speicherort
	 */
	public void genIndex(File dir) {
		try {
			PrintWriter out = new PrintWriter(new FileWriter(dir + "index.txt"));
			out.println("+ ZDFmediathek");
			out.println("|");
			ListIterator<SuperAsset> it = contentList.listIterator();
			while (it.hasNext()) {
				SuperAsset element = it.next();
				out.println("|");
				out.println("+---+" + element.getID() + " " + element.getTitle());
				ListIterator<SuperAsset> subit = element.list.listIterator();
				while (subit.hasNext()) {
					SuperAsset subelement = subit.next();
					out.println("|   |");
					out.println("|   +" + subelement.getsubID() + " " + subelement.getsubtitle());
				}
			}
			out.close();
			
		}
		catch (IOException e) {
			System.err.println(e.toString());
		}
		
	}
	
	/**
	 * Erstellt aus den Daten einen RSS-Feed im XML-Format
	 * @param dir Speicherort
	 */
	public void genFeeds(File dir) {
		try {
			ListIterator<SuperAsset> it = contentList.listIterator();
			while (it.hasNext()) {
				SuperAsset element = it.next();
				PrintWriter out = new PrintWriter(new FileWriter(dir + File.separator + element.id + "_" +element.title + ".xml"));
				out.println("<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>");
				out.println("<rss version=\"2.0\">");
				out.println("<channel>");
				out.println("    <title>" + element.getID() + " - " + element.getTitle() + "</title>");
				out.println("    <link>" + element.getURL() + "</link>");
				out.println("    <description>Kurze Beschreibung des Feeds</description>");
				out.println("    <language>de-de</language>");
	
				ListIterator<SuperAsset> subit = element.list.listIterator();
				while (subit.hasNext()) {
					Asset subelement = (Asset) subit.next();					
					out.println("    <item>");
					out.println("      <title>" + subelement.getsubtitle() + "</title>");
					out.println("	   <enclosure url=\"" + subelement.getMMS()	+ "\" type=\"video/wmv\" />");
					out.println("      <link>" + subelement.getURL() + "</link>");
					out.println("      <guid>" + subelement.getsubID() + "</guid>");
					out.println("    </item>");

				}
				out.println("  </channel>");
				out.println("</rss>");
				out.close();
			}
			
		}
		catch (IOException e) {
			System.err.println(e.toString());
		}
	}
}
