


import java.io.*;
import java.net.*;

public class RetrieveData {

	/**
	 * Stellt Verbindung zum Server her und liefert einen Mitschnitt seiner Antwort als String
	 * @param address Webadresse des Servers
	 * @return Antwort des Servers
	 */	
	public static String requestStringFromServer(String address) {
		String asset = "";
		try {
			URL url = new URL(address);
			StringWriter out = new StringWriter();
			BufferedReader in = new BufferedReader(new InputStreamReader (url.openStream()));
			int read;
			while ((read = in.read()) != -1) {
				out.write(read);
			}
			asset = out.toString();
			out.close();
			in.close();
			if (asset.length() == 0) {
				throw new AssetException(0);
			}
		}
		catch (MalformedURLException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (IOException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return asset;
	
	}

	/**
	 * Liest eine beliebige Textdatei ein und liefert dessen Inhalt als String zurück
	 * @param filename Name der auszulesenden Datei
	 * @return Inhalt der Datei
	 */	
	public static String requestStringFromFile(String filename) {
		String asset = "";
		try {
			StringWriter out = new StringWriter();
			BufferedReader in = new BufferedReader(new FileReader(filename));
			int read;
			while ((read = in.read()) != -1) {
				out.write(read);
			}
			asset = out.toString();
			out.close();
			in.close();
			if (asset.length() == 0) {
				throw new AssetException(0);
			}
		}
		catch (MalformedURLException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (IOException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return asset;
	
	}

	/**
	 * Stellt Verbindung zum Server her und schreibt den Mitschnitt seiner Antwort als Textdatei
	 * @param address Webadresse des Servers
	 * @param filename Dateiname zur Speicherung der Serverantwort
	 */
	public static void requestFileFromServer(String address, String filename) {
		try {
			URL url = new URL(address);
			FileWriter out = new FileWriter(filename);
			BufferedReader in = new BufferedReader(new InputStreamReader (url.openStream()));
			int read;
			if ((read = in.read()) == -1) {
				throw new AssetException(0);
			}
			else out.write(read);
			while ((read = in.read()) != -1) {
				out.write(read);
			}
			out.close();
			in.close();
		}
		catch (MalformedURLException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (IOException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
	}

}
