/**
 * @author Sebastian Raß
 * @version 2007-10-27
 *
 */

import java.io.*;
import java.net.*;
import java.util.*;

public class SuperAsset {
	
/*
 * Datenfelder
 */
	protected String id;
	protected String title;
	protected String subid;
	protected String subtitle;
	protected String url;
	protected String mms;
	protected String content;
	LinkedList list = new LinkedList();
	
	/** TODO
	 * Zugriff über Datenfelder oder get-Methoden?
	 */
	
/*
 * KONSTRUKTOR
 */
	
	/**
	 * Erzeugt ein neues SuperAsset-Objekt
	 * @param url relativer Pfad zur Superasset-Datei
	 */
	public SuperAsset(String url) {
		this.url = url;
		this.content = requestStringFromServer("http://www.zdf.de" + url + "?&bw=dsl2000&pp=wmp&view=navJson");
		String[] titleID = parseTitleID(url);  
		this.title = titleID[0];
		this.id = titleID[1];
		System.out.println("SuperAsset: " + title);
	}
	/**
	 * Erzeugt ein neues SuperAsset-Objekt
	 * @param url relativer Pfad zur Superasset-Datei
	 * @param parentUrl relativer Pfad zur Superasset-Datei
	 */
	public SuperAsset(String url, String parentUrl) {
		this.url = url;
		this.content = requestStringFromServer("http://www.zdf.de" + url + "?&bw=dsl2000&pp=wmp&view=navJson");
		String[] titleID = parseTitleID(parentUrl + "/");  
		this.title = titleID[0];
		this.id = titleID[1];
		this.list = createSubList(url);
	}

/*
 * GET-Methoden
 */
	
	/**
	 * Liest das Datenfeld für die Themen-ID aus
	 * 
	 * @return Themen-ID
	 */
	public String getID() {
		return this.id;
	}

	/**
	 * Liest das Datenfeld für den Thementitel aus
	 * 
	 * @return Thementitel
	 */
	public String getTitle() {
		return this.title;
	}

	/**
	 * Liest das Datenfeld für dem Link zur SuperAsset-File aus
	 * 
	 * @return Link zur Asset-File
	 */
	public String getURL() {
		return this.url;
	}

/*
 * Dummy-GET-Methoden
 */

	/**
	 * Liest das Datenfeld für die Sendungs-ID aus
	 * @return Sendungs-ID
	 */
	public String getsubID() {
		return "Parent asset has no subid";
	}

	/**
	 * Liest das Datenfeld für den Sendungstitel aus
	 * @return Sendungstitel
	 */
	public String getsubtitle() {
		return "Parent asset has no sutitle";
	}

	/**
	 * Liest das Datenfeld für den ASX-Link aus
	 * @return ASX-Link
	 */
	public String getASX() {
		return "Parent asset has no asx-link";
	}

	/**
	 * Liest das Datenfeld für den MMS-Link aus
	 * @return MMS-Link
	 */
	public String getMMS() {
		return "Parent asset has no mms-link";
	}

	/**
	 * Liest das Datenfeld für den Medien-Typ aus
	 * @return Medien-Typ
	 */
	public String getDisplayType() {
		return "Parent asset has no specific displaytype";
	}

/*
 * PARSE-Methoden
 */
	
	/**
	 * Extrahiert aus dem Inhalt die relativen Pfade zu den Themen
	 * @param content Content-Seite als String
	 * @return relativen Pfad zu den Themen
	 */
	public static String parseURL(String content) {
		String url ="";
	/*
	 * gültige Link-Adressen:
	 * <a href=\"/ZDFmediathek/content/heute-journal/228?reset=true\">
	 * <a href=\"/ZDFmediathek/content/heute_100SEC/257404\">
	 */
		String before = "<a href=\\\"/ZDFmediathek/content/";
		String shortAfter = "\\\">";
		String longAfter = "?reset=true";
		int start = content.indexOf(before);
		if (start != -1) {
			content = content.substring(start + 10);
			int shortURL = content.indexOf(shortAfter);
			if (shortURL != -1) {
				int longURL = content.substring(0, shortURL).indexOf(longAfter); 
				if (longURL != -1) {
					return url = content.substring(0, longURL);
				}
				content = content.substring(url.length());
				return url = content.substring(0, shortURL);
			}
		}
		return url;
	}

	/**
	 * Extrahiert aus dem realtiven Pfad zum Thema den Titel und die ID der Themengruppe
	 * @param url String in der Form /ZDFmediathek/content/TITEL/ID
	 * @return Titel und ID der Themengruppe
	 */
	protected static String[] parseTitleID(String url) {
		String[] info = new String[2];
		String before = "/ZDFmediathek/content/";
		String separator = "/";
		int start = url.indexOf(before);
		if (start != -1) {
			url = url.substring(start + before.length());
		}
		int endOfTitle = url.indexOf(separator);
		if (endOfTitle != -1) {
			info[0] = url.substring(0, endOfTitle);
			url = url.substring(endOfTitle + 1);
		}
		int endOfID =  url.indexOf(separator);
		if (endOfID != -1) {
			info[1] = url.substring(0, endOfID);
		}
		//System.out.println(superTitle);
		return info;
	}

	/**
	 * Extrahiert aus dem realtiven Pfad zum Thema den Titel und die ID der Themengruppe
	 * @param url String in der Form /ZDFmediathek/content/TITEL/ID
	 * @return Titel und ID der Themengruppe
	 */
	public static String parseTitle(String url) {
		String title = "";
		String before = "/ZDFmediathek/content/";
		String separator = "/";
		int start = url.indexOf(before);
		if (start != -1) {
			url = url.substring(start + before.length());
		}
		int endOfTitle = url.indexOf(separator);
		if (endOfTitle != -1) {
			title = url.substring(0, endOfTitle);
			url = url.substring(endOfTitle + 1);
		}
		System.out.println("parseTitle: " + title);
		return title;
	}
	
	/**
	 * Sucht nach dem ersten Auftauchen eines relativen URL der Form "/ZDFmediathek/content/"
	 * @param content Zu durchsuchender String
	 * @return index index des ersten Auftauchens
	 */
	public static int endofUrl(String content) {
		int result = 0;
		String before = "/ZDFmediathek/content/";
		String separator = "/";
		int start = content.indexOf(before);
		if (start != -1) {
			int endOfTitle = content.substring(start + before.length()).indexOf(separator);
			if (endOfTitle != -1) {
				int endOfID =  content.substring(endOfTitle + 1).indexOf(separator);
				result += start + endOfTitle + endOfID;
			}
		}
		return result;
	}
	
	/**
	 * Erzeugt eine Sendungsliste, die in jedem SuperAsset-Objekt gespeichert wird
	 * @param parentUrl relativer Pfad des SuperAsset
	 * @return Sendungsliste
	 */
	public LinkedList createSubList(String parentUrl) {
		while (SuperAsset.parseURL(content) != "") {
			String url = SuperAsset.parseURL(content); 
			if (url != "") {
				content = content.substring(content.indexOf(url) + url.length());
				System.out.println("-----adding asset-------------------");
				String asset = SuperAsset.requestStringFromServer("http://www.zdf.de" + url + "?&bw=dsl2000&pp=wmp&view=navJson");
				if (!Asset.parseDisplaytype(asset).equalsIgnoreCase("video")) {
					System.out.println(Asset.parseDisplaytype(content));
					System.out.println("Warning: Invalid media type. Element left out ...");
					System.out.println("-----aborted-------------------");
				}
				else {
					SuperAsset element = new Asset(url, parentUrl);
					if (list.add(element)) System.out.println("-----completed-------------------");
				}
			}
			content = content.substring(SuperAsset.endofUrl(content));
		}
		return list;
	}
	
	
/*
 * Daten-Quellen
 */
	
	/**
	 * Stellt Verbindung zum Server her und liefert einen Mitschnitt seiner Antwort als String
	 * @param address Webadresse des Servers
	 * @return Antwort des Servers
	 */	
	public static String requestStringFromServer(String address) {
		String asset = "";
		try {
			URL url = new URL(address);
			StringWriter out = new StringWriter();
			BufferedReader in = new BufferedReader(new InputStreamReader (url.openStream()));
			int read;
			while ((read = in.read()) != -1) {
				out.write(read);
			}
			asset = out.toString();
			out.close();
			in.close();
			if (asset.length() == 0) {
				throw new AssetException(0);
			}
		}
		catch (MalformedURLException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (IOException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return asset;
	
	}

	/**
	 * Liest eine beliebige Textdatei ein und liefert dessen Inhalt als String zurück
	 * @param filename Name der auszulesenden Datei
	 * @return Inhalt der Datei
	 */	
	public static String requestStringFromFile(String filename) {
		String asset = "";
		try {
			StringWriter out = new StringWriter();
			BufferedReader in = new BufferedReader(new FileReader(filename));
			int read;
			while ((read = in.read()) != -1) {
				out.write(read);
			}
			asset = out.toString();
			out.close();
			in.close();
			if (asset.length() == 0) {
				throw new AssetException(0);
			}
		}
		catch (MalformedURLException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (IOException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		return asset;
	
	}

	/**
	 * Stellt Verbindung zum Server her und schreibt den Mitschnitt seiner Antwort als Textdatei
	 * @param address Webadresse des Servers
	 * @param filename Dateiname zur Speicherung der Serverantwort
	 */
	public static void requestFileFromServer(String address, String filename) {
		try {
			URL url = new URL(address);
			FileWriter out = new FileWriter(filename);
			BufferedReader in = new BufferedReader(new InputStreamReader (url.openStream()));
			int read;
			if ((read = in.read()) == -1) {
				throw new AssetException(0);
			}
			else out.write(read);
			while ((read = in.read()) != -1) {
				out.write(read);
			}
			out.close();
			in.close();
		}
		catch (MalformedURLException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (IOException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
		catch (AssetException e) {
			System.err.println(e.toString());
			System.exit(1);
		}
	}

	
/*
 * sonstige Methoden
 */
	
	/**
	 * Prüft, ob eine Datei eine Asset-Beschreibung enthält
	 * @param descriptionFile Die zu prüfende Datei (als String)
	 */
	public static boolean isAssetfile(String descriptionFile) {
		boolean asset = false;
		if (descriptionFile.indexOf("assetUrl") != -1) asset = true;
		return asset;
	}
	

}
